@@ -1,10 +1,10 @@
 from django.contrib.auth.models import User
 from django.core.cache import cache
-from django.test import TestCase
+from django.test import override_settings, TestCase
 
 
+@override_settings(ROOT_URLCONF='redis_admin.tests.test_urls')
 class RedisAdminSanityTests(TestCase):
-    urls = 'redis_admin.tests.test_urls'
 
     def setUp(self):
         self.user = User.objects.create_superuser('test', 'test@test.com', 'password')
@@ -15,14 +15,14 @@ class RedisAdminSanityTests(TestCase):
         self.assertEqual(200, response.status_code)
 
 
+@override_settings(ROOT_URLCONF='redis_admin.tests.test_urls')
 class RedisAdminViewsTests(TestCase):
-    urls = 'redis_admin.tests.test_urls'
 
     def setUp(self):
         self.user = User.objects.create_superuser('test', 'test@test.com', 'password')
         self.client.login(username=self.user.username, password='password')
 
-        cache._client.set('test-redis-admin', 'test')
+        cache.master_client.set('test-redis-admin', 'test')
 
     def test_index(self):
         response = self.client.get('/admin/redis_admin/manage/')
@@ -41,4 +41,4 @@ class RedisAdminViewsTests(TestCase):
         self.assertEqual(302, response.status_code)
 
     def tearDown(self):
-        cache._client.delete('test-redis-admin')
+        cache.master_client.delete('test-redis-admin')
